#!/bin/bash
MANETS_BIN="$MANETS_HOME/thesis/bin"
MANETS_LOG="$MANETS_HOME/thesis/log"
MANETS_TEST_BIN="$MANETS_HOME/thesis/test/bin"

ENC_LOG_PREFIX="encryption_";
DEC_LOG_PREFIX="decryption_";
USC="_";
SH=".sh"

runfunction()
{
  NEIGH_NODES=$1
  SPLIT_COUNT=$2
  RUN_ITR=$3
  echo "NN=$NEIGH_NODES SC=$SPLIT_COUNT RUN=$RUN_ITR"

  ENC_LOG="$ENC_LOG_PREFIX$NEIGH_NODES$USC$SPLIT_COUNT$USC$RUN_ITR.log"
  DEC_LOG="$DEC_LOG_PREFIX$NEIGH_NODES$USC$SPLIT_COUNT$USC$RUN_ITR.log"
  echo "$ENC_LOG"
  echo "$DEC_LOG"
  for sc_name in `ls df_add_msg*.sh | cut -d '.' -f1`
  do

    # Start the main program
    $MANETS_BIN/manets_simulation -r &
  
    # Run the tests
    sleep 5
    $MANETS_TEST_BIN/$sc_name$SH
    sleep 5
    mv $MANETS_LOG/encryption_exec_time.log $MANETS_LOG/$sc_name$USC$ENC_LOG
    mv $MANETS_LOG/decryption_exec_time.log $MANETS_LOG/$sc_name$USC$DEC_LOG
  
    # End the main program
    pkill -2  -o manets_sim
  
    # Wait for all the processes to die
    while : 
    do
      pgrep manets_sim > /dev/null || break
    sleep 1
    done
  done
}

# Neighboring nodes=10 and number of groups=2 
for sc in 2
do
  # Compile  with specific SENDER_MSG_SPLIT_COUNT and NEIGHBORING_NODES
  echo "$MANETS_BIN/compiled.sh -DNEIGHBORING_NODES=10 -DSENDER_MSG_SPLIT_COUNT=$sc -DEXP_DIST_MEAN=50.0"
  $MANETS_BIN/compiled.sh -DNEIGHBORING_NODES=10 -DSENDER_MSG_SPLIT_COUNT=$sc -DEXP_DIST_MEAN=50.0

  i=1
  while [ $i -le 20 ]
  do
    runfunction 10 $sc $i
    i=`expr $i + 1`
  done
done

# Neighboring nodes=10 and number of groups=5
for sc in 5
do
  # Compile  with specific SENDER_MSG_SPLIT_COUNT and NEIGHBORING_NODES
  echo "$MANETS_BIN/compiled.sh -DNEIGHBORING_NODES=10 -DSENDER_MSG_SPLIT_COUNT=$sc -DEXP_DIST_MEAN=50.0"
  $MANETS_BIN/compiled.sh -DNEIGHBORING_NODES=10 -DSENDER_MSG_SPLIT_COUNT=$sc -DEXP_DIST_MEAN=50.0

  i=1
  while [ $i -le 20 ]
  do
    runfunction 10 $sc $i
    i=`expr $i + 1`
  done
done

# Neighboring nodes=10 and number of groups=10
for sc in 10 
do
  # Compile  with specific SENDER_MSG_SPLIT_COUNT and NEIGHBORING_NODES
  echo "$MANETS_BIN/compiled.sh -DNEIGHBORING_NODES=10 -DSENDER_MSG_SPLIT_COUNT=$sc -DEXP_DIST_MEAN=50.0"
  $MANETS_BIN/compiled.sh -DNEIGHBORING_NODES=10 -DSENDER_MSG_SPLIT_COUNT=$sc -DEXP_DIST_MEAN=50.0

  i=1
  while [ $i -le 20 ]
  do
    runfunction 10 $sc $i
    i=`expr $i + 1`
  done
done

# Neighboring nodes=15 and number of groups=2
for sc in 2
do
  # Compile  with specific SENDER_MSG_SPLIT_COUNT and NEIGHBORING_NODES
  echo "$MANETS_BIN/compiled.sh -DNEIGHBORING_NODES=15 -DSENDER_MSG_SPLIT_COUNT=$sc -DEXP_DIST_MEAN=50.0"
  $MANETS_BIN/compiled.sh -DNEIGHBORING_NODES=15 -DSENDER_MSG_SPLIT_COUNT=$sc -DEXP_DIST_MEAN=50.0

  i=1
  while [ $i -le 20 ]
  do
    runfunction 15 $sc $i
    i=`expr $i + 1`
  done
done

# Neighboring nodes=15 and number of groups=7
for sc in 7
do
  # Compile  with specific SENDER_MSG_SPLIT_COUNT and NEIGHBORING_NODES
  echo "$MANETS_BIN/compiled.sh -DNEIGHBORING_NODES=15 -DSENDER_MSG_SPLIT_COUNT=$sc -DEXP_DIST_MEAN=50.0"
  $MANETS_BIN/compiled.sh -DNEIGHBORING_NODES=15 -DSENDER_MSG_SPLIT_COUNT=$sc -DEXP_DIST_MEAN=50.0

  i=1
  while [ $i -le 20 ]
  do
    runfunction 15 $sc $i
    i=`expr $i + 1`
  done
done

# Neighboring nodes=15 and number of groups=15
for sc in 15
do
  # Compile  with specific SENDER_MSG_SPLIT_COUNT and NEIGHBORING_NODES
  echo "$MANETS_BIN/compiled.sh -DNEIGHBORING_NODES=15 -DSENDER_MSG_SPLIT_COUNT=$sc -DEXP_DIST_MEAN=50.0"
  $MANETS_BIN/compiled.sh -DNEIGHBORING_NODES=15 -DSENDER_MSG_SPLIT_COUNT=$sc -DEXP_DIST_MEAN=50.0

  i=1
  while [ $i -le 20 ]
  do
    runfunction 15 $sc $i
    i=`expr $i + 1`
  done
done

# Neighboring nodes=20 and number of groups=2
for sc in 2
do
  # Compile  with specific SENDER_MSG_SPLIT_COUNT and NEIGHBORING_NODES
  echo "$MANETS_BIN/compiled.sh -DNEIGHBORING_NODES=20 -DSENDER_MSG_SPLIT_COUNT=$sc -DEXP_DIST_MEAN=50.0"
  $MANETS_BIN/compiled.sh -DNEIGHBORING_NODES=20 -DSENDER_MSG_SPLIT_COUNT=$sc -DEXP_DIST_MEAN=50.0

  i=1
  while [ $i -le 20 ]
  do
    runfunction 20 $sc $i
    i=`expr $i + 1`
  done
done

# Neighboring nodes=20 and number of groups=10
for sc in 10
do
  # Compile  with specific SENDER_MSG_SPLIT_COUNT and NEIGHBORING_NODES
  echo "$MANETS_BIN/compiled.sh -DNEIGHBORING_NODES=20 -DSENDER_MSG_SPLIT_COUNT=$sc -DEXP_DIST_MEAN=50.0"
  $MANETS_BIN/compiled.sh -DNEIGHBORING_NODES=20 -DSENDER_MSG_SPLIT_COUNT=$sc -DEXP_DIST_MEAN=50.0

  i=1
  while [ $i -le 20 ]
  do
    runfunction 20 $sc $i
    i=`expr $i + 1`
  done
done

# Neighboring nodes=20 and number of groups=20
for sc in 20
do
  # Compile  with specific SENDER_MSG_SPLIT_COUNT and NEIGHBORING_NODES
  echo "$MANETS_BIN/compiled.sh -DNEIGHBORING_NODES=20 -DSENDER_MSG_SPLIT_COUNT=$sc -DEXP_DIST_MEAN=50.0"
  $MANETS_BIN/compiled.sh -DNEIGHBORING_NODES=20 -DSENDER_MSG_SPLIT_COUNT=$sc -DEXP_DIST_MEAN=50.0

  i=1
  while [ $i -le 20 ]
  do
    runfunction 20 $sc $i
    i=`expr $i + 1`
  done
done

